Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrCreateChartRequestCancelled = errors.New("create chart request is cancelled")
ErrCreateChartRequestCancelled contains error message about cancelled create chart request.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
render.UnimplementedChartAPIServer
// contains filtered or unexported fields
}
Server implements render.ChartAPIServer.
func NewServer ¶
func NewServer(ctx context.Context, log *zerolog.Logger, apiCfg config.APIConfig, rendererCfg config.RendererConfig) (*Server, error)
NewServer configures needed connections and returns a new Server.
func (*Server) CreateChart ¶
func (s *Server) CreateChart(ctx context.Context, req *render.CreateChartRequest) (*render.ChartReply, error)
CreateChart implements render.ChartAPIServer.CreateChart.
func (*Server) GetChart ¶
func (s *Server) GetChart(_ context.Context, req *render.GetChartRequest) (*render.ChartReply, error)
GetChart implements render.ChartAPIServer.GetChart. It returns codes.NotFound until storage is implemented.
Click to show internal directories.
Click to hide internal directories.